'use strict';

var mp = require('miniapp-render/dist/ali');

var cache = mp.$$adapter.cache;
/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/input.html
 */

var input = {
  PROPS: [{
    name: 'value',
    get: function get(domNode) {
      return domNode.value || '';
    }
  }, {
    name: 'type',
    get: function get(domNode) {
      var value = domNode.type || 'text';
      return value !== 'password' ? value : 'text';
    }
  }, {
    name: 'password',
    get: function get(domNode) {
      return domNode.type !== 'password' ? !!domNode.getAttribute('password') : true;
    }
  }, {
    name: 'placeholder',
    get: function get(domNode) {
      return domNode.placeholder;
    }
  }, {
    name: 'placeholderStyle',
    get: function get(domNode) {
      return domNode.getAttribute('placeholder-style') || '';
    }
  }, {
    name: 'placeholderClass',
    get: function get(domNode) {
      return domNode.getAttribute('placeholder-class') || 'input-placeholder';
    }
  }, {
    name: 'disabled',
    get: function get(domNode) {
      return domNode.disabled;
    }
  }, {
    name: 'maxlength',
    get: function get(domNode) {
      var value = parseInt(domNode.maxlength, 10);
      return !isNaN(value) ? value : 140;
    }
  }, {
    name: 'cursorSpacing',
    get: function get(domNode) {
      return +domNode.getAttribute('cursor-spacing') || 0;
    }
  }, {
    name: 'autoFocus',
    get: function get(domNode) {
      return !!domNode.getAttribute('autofocus');
    }
  }, {
    name: 'focus',
    get: function get(domNode) {
      return !!domNode.getAttribute('focus');
    }
  }, {
    name: 'confirmType',
    get: function get(domNode) {
      return domNode.getAttribute('confirm-type') || 'done';
    }
  }, {
    name: 'confirmHold',
    get: function get(domNode) {
      return !!domNode.getAttribute('confirm-hold');
    }
  }, {
    name: 'cursor',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('cursor'), 10);
      return !isNaN(value) ? value : -1;
    }
  }, {
    name: 'selectionStart',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('selection-start'), 10);
      return !isNaN(value) ? value : -1;
    }
  }, {
    name: 'selectionEnd',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('selection-end'), 10);
      return !isNaN(value) ? value : -1;
    }
  }, {
    name: 'adjustPosition',
    get: function get(domNode) {
      var value = domNode.getAttribute('adjust-position');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'checked',
    get: function get(domNode) {
      return !!domNode.getAttribute('checked');
    }
  }, {
    name: 'color',
    get: function get(domNode) {
      return domNode.getAttribute('color') || '#09BB07';
    }
  }],
  handles: {
    onInputInput: function onInputInput(evt) {
      if (!this.domNode) return;
      this.domNode.value = evt.detail.value;
      this.callEvent('input', evt);
    },
    onInputFocus: function onInputFocus(evt) {
      this._inputOldValue = this.domNode.value;
      this.callSimpleEvent('focus', evt);
    },
    onInputBlur: function onInputBlur(evt) {
      if (!this.domNode) return;
      this.domNode.setAttribute('focus', false);

      if (this._inputOldValue !== undefined && this.domNode.value !== this._inputOldValue) {
        this._inputOldValue = undefined;
        this.callEvent('change', evt);
      }

      this.callSimpleEvent('blur', evt);
    },
    onInputConfirm: function onInputConfirm(evt) {
      this.callSimpleEvent('confirm', evt);
    },
    onInputKeyBoardHeightChange: function onInputKeyBoardHeightChange(evt) {
      this.callSimpleEvent('keyboardheightchange', evt);
    },
    onRadioChange: function onRadioChange(evt) {
      var window = cache.getWindow(this.pageId);
      var domNode = this.domNode;
      var value = evt.detail.value;
      var name = domNode.name;
      var otherDomNodes = window.document.querySelectorAll("input[name=" + name + "]") || [];

      if (value === domNode.value) {
        domNode.checked = true;

        for (var _iterator = otherDomNodes, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
          var _ref;

          if (_isArray) {
            if (_i >= _iterator.length) break;
            _ref = _iterator[_i++];
          } else {
            _i = _iterator.next();
            if (_i.done) break;
            _ref = _i.value;
          }

          var otherDomNode = _ref;

          if (otherDomNode.type === 'radio' && otherDomNode !== domNode) {
            otherDomNode.checked = false;
          }
        }
      }

      this.callEvent('change', evt);
    },
    onCheckboxChange: function onCheckboxChange(evt) {
      var domNode = this.domNode;
      var value = evt.detail.value || [];

      if (value.indexOf(domNode.value) >= 0) {
        domNode.checked = true;
      } else {
        domNode.checked = false;
      }

      this.callEvent('change', evt);
    }
  }
};

exports.default = input;
