'use strict';

var mp = require('miniapp-render/dist/ali');

var _mp$$$adapter = mp.$$adapter,
    cache = _mp$$$adapter.cache,
    tool = _mp$$$adapter.tool;
/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/live-player.html
 */

var livePlayer = {
  PROPS: [{
    name: 'src',
    get: function get(domNode) {
      var window = cache.getWindow(domNode.$$pageId);
      return domNode.src ? tool.completeURL(domNode.src, window.location.origin, true) : '';
    }
  }, {
    name: 'mode',
    get: function get(domNode) {
      return domNode.getAttribute('mode') || 'live';
    }
  }, {
    name: 'autoplay',
    get: function get(domNode) {
      return !!domNode.getAttribute('autoplay');
    }
  }, {
    name: 'muted',
    get: function get(domNode) {
      return !!domNode.getAttribute('muted');
    }
  }, {
    name: 'orientation',
    get: function get(domNode) {
      return domNode.getAttribute('orientation') || 'vertical';
    }
  }, {
    name: 'objectFit',
    get: function get(domNode) {
      return domNode.getAttribute('object-fit') || 'contain';
    }
  }, {
    name: 'backgroundMute',
    get: function get(domNode) {
      return !!domNode.getAttribute('background-mute');
    }
  }, {
    name: 'minCache',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('min-cache'), 10);
      return !isNaN(value) ? value : 1;
    }
  }, {
    name: 'maxCache',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('max-cache'), 10);
      return !isNaN(value) ? value : 3;
    }
  }, {
    name: 'soundMode',
    get: function get(domNode) {
      return domNode.getAttribute('sound-mode') || 'speaker';
    }
  }, {
    name: 'autoPauseIfNavigate',
    get: function get(domNode) {
      var value = domNode.getAttribute('auto-pause-if-navigate');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'autoPauseIfOpenNative',
    get: function get(domNode) {
      var value = domNode.getAttribute('auto-pause-if-open-native');
      return value !== undefined ? !!value : true;
    }
  }],
  handles: {
    onLivePlayerStateChange: function onLivePlayerStateChange(evt) {
      this.callSimpleEvent('statechange', evt);
    },
    onLivePlayerFullScreenChange: function onLivePlayerFullScreenChange(evt) {
      this.callSimpleEvent('fullscreenchange', evt);
    },
    onLivePlayerNetStatus: function onLivePlayerNetStatus(evt) {
      this.callSimpleEvent('netstatus', evt);
    }
  }
};

exports.default = livePlayer;
