'use strict';

var mp = require('miniapp-render/dist/ali');

var _mp$$$adapter = mp.$$adapter,
    cache = _mp$$$adapter.cache,
    tool = _mp$$$adapter.tool;
/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/video.html
 */

var video = {
  PROPS: [{
    name: 'src',
    get: function get(domNode) {
      var window = cache.getWindow(domNode.$$pageId);
      return domNode.src ? tool.completeURL(domNode.src, window.location.origin, true) : '';
    }
  }, {
    name: 'duration',
    get: function get(domNode) {
      return +domNode.getAttribute('duration') || 0;
    }
  }, {
    name: 'controls',
    get: function get(domNode) {
      return domNode.controls;
    }
  }, {
    name: 'danmuList',
    get: function get(domNode) {
      var value = domNode.getAttribute('danmu-list');
      return value !== undefined ? value : [];
    }
  }, {
    name: 'danmuBtn',
    get: function get(domNode) {
      return !!domNode.getAttribute('danmu-btn');
    }
  }, {
    name: 'enableDanmu',
    get: function get(domNode) {
      return !!domNode.getAttribute('enable-danmu');
    }
  }, {
    name: 'autoplay',
    get: function get(domNode) {
      return domNode.autoplay;
    }
  }, {
    name: 'loop',
    get: function get(domNode) {
      return domNode.loop;
    }
  }, {
    name: 'muted',
    get: function get(domNode) {
      return domNode.muted;
    }
  }, {
    name: 'initialTime',
    get: function get(domNode) {
      return +domNode.getAttribute('initial-time') || 0;
    }
  }, {
    name: 'direction',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('direction'), 10);
      return !isNaN(value) ? value : -1;
    }
  }, {
    name: 'showProgress',
    get: function get(domNode) {
      var value = domNode.getAttribute('show-progress');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'showFullscreenBtn',
    get: function get(domNode) {
      var value = domNode.getAttribute('show-fullscreen-btn');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'showPlayBtn',
    get: function get(domNode) {
      var value = domNode.getAttribute('show-play-btn');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'showCenterPlayBtn',
    get: function get(domNode) {
      var value = domNode.getAttribute('show-center-play-btn');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'enableProgressGesture',
    get: function get(domNode) {
      var value = domNode.getAttribute('enable-progress-gesture');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'objectFit',
    get: function get(domNode) {
      return domNode.getAttribute('object-fit') || 'contain';
    }
  }, {
    name: 'poster',
    get: function get(domNode) {
      var window = cache.getWindow(domNode.$$pageId);
      return domNode.poster ? tool.completeURL(domNode.poster, window.location.origin, true) : '';
    }
  }, {
    name: 'showMuteBtn',
    get: function get(domNode) {
      return !!domNode.getAttribute('show-mute-btn');
    }
  }, {
    name: 'title',
    get: function get(domNode) {
      return domNode.getAttribute('title') || '';
    }
  }, {
    name: 'playBtnPosition',
    get: function get(domNode) {
      return domNode.getAttribute('play-btn-position') || 'bottom';
    }
  }, {
    name: 'enablePlayGesture',
    get: function get(domNode) {
      return !!domNode.getAttribute('enable-play-gesture');
    }
  }, {
    name: 'autoPauseIfNavigate',
    get: function get(domNode) {
      var value = domNode.getAttribute('auto-pause-if-navigate');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'autoPauseIfOpenNative',
    get: function get(domNode) {
      var value = domNode.getAttribute('auto-pause-if-open-native');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'vslideGesture',
    get: function get(domNode) {
      return !!domNode.getAttribute('vslide-gesture');
    }
  }, {
    name: 'vslideGestureInFullscreen',
    get: function get(domNode) {
      var value = domNode.getAttribute('vslide-gesture-in-fullscreen');
      return value !== undefined ? !!value : true;
    }
  }],
  handles: {
    onVideoPlay: function onVideoPlay(evt) {
      this.callSimpleEvent('play', evt);
    },
    onVideoPause: function onVideoPause(evt) {
      this.callSimpleEvent('pause', evt);
    },
    onVideoEnded: function onVideoEnded(evt) {
      this.callSimpleEvent('ended', evt);
    },
    onVideoTimeUpdate: function onVideoTimeUpdate(evt) {
      if (!this.domNode) return;
      this.domNode.$$setAttributeWithoutUpdate('currentTime', evt.detail.currentTime);
      this.callSimpleEvent('timeupdate', evt);
    },
    onVideoFullScreenChange: function onVideoFullScreenChange(evt) {
      this.callSimpleEvent('fullscreenchange', evt);
    },
    onVideoWaiting: function onVideoWaiting(evt) {
      this.callSimpleEvent('waiting', evt);
    },
    onVideoError: function onVideoError(evt) {
      this.callSimpleEvent('error', evt);
    },
    onVideoProgress: function onVideoProgress(evt) {
      if (!this.domNode) return;
      this.domNode.$$setAttributeWithoutUpdate('buffered', evt.detail.buffered);
      this.callSimpleEvent('progress', evt);
    }
  }
};

exports.default = video;
