'use strict';

var mp = require('miniapp-render/dist/wechat');

var _mp$$$adapter = mp.$$adapter,
    cache = _mp$$$adapter.cache,
    tool = _mp$$$adapter.tool;
/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/live-pusher.html
 */

var livePusher = {
  PROPS: [{
    name: 'url',
    get: function get(domNode) {
      var window = cache.getWindow(domNode.$$pageId);
      var url = domNode.getAttribute('url');
      return url ? tool.completeURL(url, window.location.origin, true) : '';
    }
  }, {
    name: 'mode',
    get: function get(domNode) {
      return domNode.getAttribute('mode') || 'RTC';
    }
  }, {
    name: 'autopush',
    get: function get(domNode) {
      return !!domNode.getAttribute('autopush');
    }
  }, {
    name: 'muted',
    get: function get(domNode) {
      return !!domNode.getAttribute('muted');
    }
  }, {
    name: 'enableCamera',
    get: function get(domNode) {
      var value = domNode.getAttribute('enable-camera');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'autoFocus',
    get: function get(domNode) {
      var value = domNode.getAttribute('auto-focus');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'orientation',
    get: function get(domNode) {
      return domNode.getAttribute('orientation') || 'vertical';
    }
  }, {
    name: 'beauty',
    get: function get(domNode) {
      return +domNode.getAttribute('beauty') || 0;
    }
  }, {
    name: 'whiteness',
    get: function get(domNode) {
      return +domNode.getAttribute('whiteness') || 0;
    }
  }, {
    name: 'aspect',
    get: function get(domNode) {
      return domNode.getAttribute('aspect') || '9:16';
    }
  }, {
    name: 'minBitrate',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('min-bitrate'), 10);
      return !isNaN(value) ? value : 200;
    }
  }, {
    name: 'maxBitrate',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('max-bitrate'), 10);
      return !isNaN(value) ? value : 1000;
    }
  }, {
    name: 'waitingImage',
    get: function get(domNode) {
      return domNode.getAttribute('waiting-image') || '';
    }
  }, {
    name: 'waitingImageHash',
    get: function get(domNode) {
      return domNode.getAttribute('waiting-image-hash') || '';
    }
  }, {
    name: 'zoom',
    get: function get(domNode) {
      return !!domNode.getAttribute('zoom');
    }
  }, {
    name: 'devicePosition',
    get: function get(domNode) {
      return domNode.getAttribute('device-position') || 'front';
    }
  }, {
    name: 'backgroundMute',
    get: function get(domNode) {
      return !!domNode.getAttribute('background-mute');
    }
  }, {
    name: 'mirror',
    get: function get(domNode) {
      return !!domNode.getAttribute('mirror');
    }
  }],
  handles: {
    onLivePusherStateChange: function onLivePusherStateChange(evt) {
      this.callSimpleEvent('statechange', evt);
    },
    onLivePusherNetStatus: function onLivePusherNetStatus(evt) {
      this.callSimpleEvent('netstatus', evt);
    },
    onLivePusherError: function onLivePusherError(evt) {
      this.callSimpleEvent('error', evt);
    },
    onLivePusherBgmStart: function onLivePusherBgmStart(evt) {
      this.callSimpleEvent('bgmstart', evt);
    },
    onLivePusherBgmProgress: function onLivePusherBgmProgress(evt) {
      this.callSimpleEvent('bgmprogress', evt);
    },
    onLivePusherBgmComplete: function onLivePusherBgmComplete(evt) {
      this.callSimpleEvent('bgmcomplete', evt);
    }
  }
};

exports.default = livePusher;
