'use strict';

/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/map.html
 */
var map = {
  PROPS: [{
    name: 'longitude',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('longitude'), 10);
      return !isNaN(value) ? value : 39.92;
    }
  }, {
    name: 'latitude',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('latitude'), 10);
      return !isNaN(value) ? value : 116.46;
    }
  }, {
    name: 'scale',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('scale'), 10);
      return !isNaN(value) ? value : 16;
    }
  }, {
    name: 'markers',
    get: function get(domNode) {
      var value = domNode.getAttribute('markers');
      return value !== undefined ? value : [];
    }
  }, {
    name: 'polyline',
    get: function get(domNode) {
      var value = domNode.getAttribute('polyline');
      return value !== undefined ? value : [];
    }
  }, {
    name: 'circles',
    get: function get(domNode) {
      var value = domNode.getAttribute('circles');
      return value !== undefined ? value : [];
    }
  }, {
    name: 'controls',
    get: function get(domNode) {
      var value = domNode.getAttribute('controls');
      return value !== undefined ? value : [];
    }
  }, {
    name: 'includePoints',
    get: function get(domNode) {
      var value = domNode.getAttribute('include-points');
      return value !== undefined ? value : [];
    }
  }, {
    name: 'showLocation',
    get: function get(domNode) {
      return !!domNode.getAttribute('show-location');
    }
  }, {
    name: 'polygons',
    get: function get(domNode) {
      var value = domNode.getAttribute('polygons');
      return value !== undefined ? value : [];
    }
  }, {
    name: 'subkey',
    get: function get(domNode) {
      return domNode.getAttribute('subkey') || '';
    }
  }, {
    name: 'layerStyle',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('layer-style'), 10);
      return !isNaN(value) ? value : 1;
    }
  }, {
    name: 'rotate',
    get: function get(domNode) {
      return +domNode.getAttribute('rotate') || 0;
    }
  }, {
    name: 'skew',
    get: function get(domNode) {
      return +domNode.getAttribute('skew') || 0;
    }
  }, {
    name: 'enable3D',
    get: function get(domNode) {
      return !!domNode.getAttribute('enable-3D');
    }
  }, {
    name: 'showCompass',
    get: function get(domNode) {
      return !!domNode.getAttribute('show-compass');
    }
  }, {
    name: 'enableOverlooking',
    get: function get(domNode) {
      return !!domNode.getAttribute('enable-overlooking');
    }
  }, {
    name: 'enableZoom',
    get: function get(domNode) {
      var value = domNode.getAttribute('enable-zoom');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'enableScroll',
    get: function get(domNode) {
      var value = domNode.getAttribute('enable-scroll');
      return value !== undefined ? !!value : true;
    }
  }, {
    name: 'enableRotate',
    get: function get(domNode) {
      return !!domNode.getAttribute('enable-rotate');
    }
  }, {
    name: 'enableSatellite',
    get: function get(domNode) {
      return !!domNode.getAttribute('enable-satellite');
    }
  }, {
    name: 'enableTraffic',
    get: function get(domNode) {
      return !!domNode.getAttribute('enable-traffic');
    }
  }],
  handles: {
    onMapTap: function onMapTap(evt) {
      this.callSimpleEvent('tap', evt);
    },
    onMapMarkerTap: function onMapMarkerTap(evt) {
      this.callSimpleEvent('markertap', evt);
    },
    onMapControlTap: function onMapControlTap(evt) {
      this.callSimpleEvent('controltap', evt);
    },
    onMapCalloutTap: function onMapCalloutTap(evt) {
      this.callSimpleEvent('callouttap', evt);
    },
    onMapUpdated: function onMapUpdated(evt) {
      this.callSimpleEvent('updated', evt);
    },
    onMapRegionChange: function onMapRegionChange(evt) {
      this.callSimpleEvent('regionchange', evt);
    },
    onMapPoiTap: function onMapPoiTap(evt) {
      this.callSimpleEvent('poitap', evt);
    }
  }
};

exports.default = map;
