'use strict';

var mp = require('miniapp-render/dist/wechat');

var cache = mp.$$adapter.cache;
/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/movable-view.html
 */

var movableView = {
  PROPS: [{
    name: 'direction',
    get: function get(domNode) {
      return domNode.getAttribute('direction') || 'none';
    }
  }, {
    name: 'inertia',
    get: function get(domNode) {
      return !!domNode.getAttribute('inertia');
    }
  }, {
    name: 'outOfBounds',
    get: function get(domNode) {
      return !!domNode.getAttribute('out-of-bounds');
    }
  }, {
    name: 'x',
    get: function get(domNode) {
      return +domNode.getAttribute('x') || 0;
    }
  }, {
    name: 'y',
    get: function get(domNode) {
      return +domNode.getAttribute('y') || 0;
    }
  }, {
    name: 'damping',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('damping'), 10);
      return !isNaN(value) ? value : 20;
    }
  }, {
    name: 'friction',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('friction'), 10);
      return !isNaN(value) ? value : 2;
    }
  }, {
    name: 'disabled',
    get: function get(domNode) {
      return !!domNode.getAttribute('disabled');
    }
  }, {
    name: 'scale',
    get: function get(domNode) {
      return !!domNode.getAttribute('scale');
    }
  }, {
    name: 'scaleMin',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('scale-min'), 10);
      return !isNaN(value) ? value : 0.5;
    }
  }, {
    name: 'scaleMax',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('scale-max'), 10);
      return !isNaN(value) ? value : 10;
    }
  }, {
    name: 'scaleValue',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('scale-value'), 10);
      return !isNaN(value) ? value : 1;
    }
  }, {
    name: 'animation',
    get: function get(domNode) {
      var value = domNode.getAttribute('animation');
      return value !== undefined ? !!value : true;
    }
  }],
  handles: {
    onMovableViewChange: function onMovableViewChange(evt) {
      var nodeId = evt.currentTarget.dataset.privateNodeId;
      var domNode = cache.getNode(this.pageId, nodeId);
      if (!domNode) return;
      domNode.$$setAttributeWithoutUpdate('x', evt.detail.x);
      domNode.$$setAttributeWithoutUpdate('y', evt.detail.y);
      this.callSimpleEvent('change', evt, domNode);
    },
    onMovableViewScale: function onMovableViewScale(evt) {
      var nodeId = evt.currentTarget.dataset.privateNodeId;
      var domNode = cache.getNode(this.pageId, nodeId);
      if (!domNode) return;
      domNode.$$setAttributeWithoutUpdate('x', evt.detail.x);
      domNode.$$setAttributeWithoutUpdate('y', evt.detail.y);
      domNode.$$setAttributeWithoutUpdate('scale-value', evt.detail.scale);
      this.callSimpleEvent('scale', evt, domNode);
    },
    onMovableViewHtouchmove: function onMovableViewHtouchmove(evt) {
      var nodeId = evt.currentTarget.dataset.privateNodeId;
      var domNode = cache.getNode(this.pageId, nodeId);
      if (!domNode) return;
      this.callSimpleEvent('htouchmove', evt, domNode);
    },
    onMovableViewVtouchmove: function onMovableViewVtouchmove(evt) {
      var nodeId = evt.currentTarget.dataset.privateNodeId;
      var domNode = cache.getNode(this.pageId, nodeId);
      if (!domNode) return;
      this.callSimpleEvent('vtouchmove', evt, domNode);
    }
  }
};

exports.default = movableView;
