'use strict';

/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/navigator.html
 */
var navigator = {
  PROPS: [{
    name: 'target',
    get: function get(domNode) {
      return domNode.getAttribute('target') || 'self';
    }
  }, {
    name: 'url',
    get: function get(domNode) {
      return domNode.getAttribute('url') || '';
    }
  }, {
    name: 'openType',
    get: function get(domNode) {
      return domNode.getAttribute('open-type') || 'navigate';
    }
  }, {
    name: 'delta',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('delta'), 10);
      return !isNaN(value) ? value : 1;
    }
  }, {
    name: 'appId',
    get: function get(domNode) {
      return domNode.getAttribute('app-id') || '';
    }
  }, {
    name: 'path',
    get: function get(domNode) {
      return domNode.getAttribute('path') || '';
    }
  }, {
    name: 'extraData',
    get: function get(domNode) {
      return domNode.getAttribute('extra-data') || {};
    }
  }, {
    name: 'version',
    get: function get(domNode) {
      return domNode.getAttribute('version') || 'release';
    }
  }, {
    name: 'hoverClass',
    get: function get(domNode) {
      return domNode.getAttribute('hover-class') || 'navigator-hover';
    }
  }, {
    name: 'hoverStopPropagation',
    get: function get(domNode) {
      return !!domNode.getAttribute('hover-stop-propagation');
    }
  }, {
    name: 'hoverStartTime',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('hover-start-time'), 10);
      return !isNaN(value) ? value : 50;
    }
  }, {
    name: 'hoverStayTime',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('hover-stay-time'), 10);
      return !isNaN(value) ? value : 600;
    }
  }],
  handles: {
    onNavigatorSuccess: function onNavigatorSuccess(evt) {
      this.callSimpleEvent('success', evt);
    },
    onNavigatorFail: function onNavigatorFail(evt) {
      this.callSimpleEvent('fail', evt);
    },
    onNavigatorComplete: function onNavigatorComplete(evt) {
      this.callSimpleEvent('complete', evt);
    }
  }
};

exports.default = navigator;
