'use strict';

/**
 * https://developers.weixin.qq.com/miniprogram/dev/component/swiper.html
 */
var swiper = {
  PROPS: [{
    name: 'indicatorDots',
    get: function get(domNode) {
      return !!domNode.getAttribute('mindicator-dotsin');
    }
  }, {
    name: 'indicatorColor',
    get: function get(domNode) {
      return domNode.getAttribute('indicator-color') || 'rgba(0, 0, 0, .3)';
    }
  }, {
    name: 'indicatorActiveColor',
    get: function get(domNode) {
      return domNode.getAttribute('indicator-active-color') || '#000000';
    }
  }, {
    name: 'autoplay',
    get: function get(domNode) {
      return !!domNode.getAttribute('autoplay');
    }
  }, {
    name: 'current',
    get: function get(domNode) {
      return +domNode.getAttribute('current') || 0;
    }
  }, {
    name: 'interval',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('interval'), 10);
      return !isNaN(value) ? value : 5000;
    }
  }, {
    name: 'duration',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('duration'), 10);
      return !isNaN(value) ? value : 500;
    }
  }, {
    name: 'circular',
    get: function get(domNode) {
      return !!domNode.getAttribute('circular');
    }
  }, {
    name: 'vertical',
    get: function get(domNode) {
      return !!domNode.getAttribute('vertical');
    }
  }, {
    name: 'previousMargin',
    get: function get(domNode) {
      return domNode.getAttribute('previous-margin') || '0px';
    }
  }, {
    name: 'nextMargin',
    get: function get(domNode) {
      return domNode.getAttribute('next-margin') || '0px';
    }
  }, {
    name: 'displayMultipleItems',
    get: function get(domNode) {
      var value = parseInt(domNode.getAttribute('display-multiple-items'), 10);
      return !isNaN(value) ? value : 1;
    }
  }, {
    name: 'skipHiddenItemLayout',
    get: function get(domNode) {
      return !!domNode.getAttribute('skip-hidden-item-layout');
    }
  }, {
    name: 'easingFunction',
    get: function get(domNode) {
      return domNode.getAttribute('easing-function') || 'default';
    }
  }],
  handles: {
    onSwiperChange: function onSwiperChange(evt) {
      if (!this.domNode) return;
      this.domNode.$$setAttributeWithoutUpdate('current', evt.detail.current);
      this.callSimpleEvent('change', evt);
    },
    onSwiperTransition: function onSwiperTransition(evt) {
      this.callSimpleEvent('transition', evt);
    },
    onSwiperAnimationfinish: function onSwiperAnimationfinish(evt) {
      this.callSimpleEvent('animationfinish', evt);
    }
  }
};

exports.default = swiper;
